# geoapps
Some open-source applications maintained by `Mira Geoscience <https://github.com/MiraGeoscience/geoapps>`_,
mostly in Python, leveraging the free `Geoscience ANALYST
<https://mirageoscience.com/mining-industry-software/geoscience-analyst/>`_ 3D viewer.
